@@ -105,7 +105,7 @@ class Selection(object):
         """
         Grow or shrink the rectangle size according to margins.
 
-        :param rect: rectangle
+        :param rect: Rect object
         :type rect: :py:class:`pygame.Rect`
         :return: Inflated rect
         :rtype: :py:class:`pygame.Rect`
@@ -123,7 +123,7 @@ class Selection(object):
         :return: Height in px
         :rtype: int, float
         """
-        t, _, b, _ = self.get_height()
+        t, _, b, _ = self.get_margin()
         return t + b
 
     def draw(self, surface, widget):
