@@ -41,7 +41,9 @@ class HighlightSelection(Selection):
     """
     Widget selection highlight class.
 
-    .. note:: Widget background color may not reach the entire selection area
+    .. note::
+
+        Widget background color may not reach the entire selection area
 
     :param border_width: Border width of the highlight box
     :type border_width: int
