@@ -6,6 +6,9 @@ https://github.com/ppizarror/pygame-menu
 BUTTON
 Button class, manage elements and adds entries to menu.
 
+NOTE: pygame-menu v3 will not provide new widgets or functionalities, consider
+upgrading to the latest version.
+
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
@@ -49,7 +52,7 @@ class Button(Widget):
     :param args: Optional arguments for callbacks
     :type args: any
     :param kwargs: Optional keyword arguments
-    :type kwargs: dict
+    :type kwargs: dict, any
     """
 
     def __init__(self,
@@ -134,7 +137,8 @@ class Button(Widget):
                 self.apply()
                 updated = True
 
-            elif self.mouse_enabled and event.type == pygame.MOUSEBUTTONUP:
+            elif self.mouse_enabled and event.type == pygame.MOUSEBUTTONUP and \
+                    event.button in (1, 2, 3):  # Don't consider the mouse wheel (button 4 & 5)
                 self.sound.play_click_mouse()
                 if rect.collidepoint(*event.pos):
                     self.apply()
@@ -144,7 +148,7 @@ class Button(Widget):
                 self.sound.play_click_mouse()
                 window_size = self.get_menu().get_window_size()
                 finger_pos = (event.x * window_size[0], event.y * window_size[1])
-                if rect.collidepoint(finger_pos):
+                if rect.collidepoint(*finger_pos):
                     self.apply()
                     updated = True
 
