@@ -365,7 +365,8 @@ class MenuBar(Widget):
 
         for event in events:  # type: pygame.event.Event
 
-            if self.mouse_enabled and event.type == pygame.MOUSEBUTTONUP:
+            if self.mouse_enabled and event.type == pygame.MOUSEBUTTONUP and \
+                    event.button in (1, 2, 3):  # Don't consider the mouse wheel (button 4 & 5)
                 if self._backbox_rect and self._backbox_rect.collidepoint(*event.pos):
                     self.sound.play_click_mouse()
                     self.apply()
@@ -380,7 +381,7 @@ class MenuBar(Widget):
             elif self.touchscreen_enabled and event.type == pygame.FINGERUP:
                 window_size = self.get_menu().get_window_size()
                 finger_pos = (event.x * window_size[0], event.y * window_size[1])
-                if self._backbox_rect and self._backbox_rect.collidepoint(finger_pos):
+                if self._backbox_rect and self._backbox_rect.collidepoint(*finger_pos):
                     self.sound.play_click_mouse()
                     self.apply()
                     updated = True
