@@ -265,10 +265,10 @@ class Selector(Widget):
                     event.button in (1, 2, 3):  # Don't consider the mouse wheel (button 4 & 5)
                 if rect.collidepoint(*event.pos):
                     # Check if mouse collides left or right as percentage, use only X coordinate
-                    mousex, _ = event.pos
+                    mouse_x, _ = event.pos
                     topleft, _ = rect.topleft
                     topright, _ = rect.topright
-                    dist = mousex - (topleft + self._title_size)  # Distance from label
+                    dist = mouse_x - (topleft + self._title_size)  # Distance from label
                     if dist > 0:  # User clicked the options, not label
                         # Position in percentage, if <0.5 user clicked left
                         pos = dist / float(topright - topleft - self._title_size)
@@ -283,10 +283,10 @@ class Selector(Widget):
                 finger_pos = (event.x * window_size[0], event.y * window_size[1])
                 if rect.collidepoint(*finger_pos):
                     # Check if mouse collides left or right as percentage, use only X coordinate
-                    mousex, _ = finger_pos
+                    mouse_x, _ = finger_pos
                     topleft, _ = rect.topleft
                     topright, _ = rect.topright
-                    dist = mousex - (topleft + self._title_size)  # Distance from label
+                    dist = mouse_x - (topleft + self._title_size)  # Distance from label
                     if dist > 0:  # User clicked the options, not label
                         # Position in percentage, if <0.5 user clicked left
                         pos = dist / float(topright - topleft - self._title_size)
